searchNodes=[{"doc":"Module containing all basic functionality needed for validation.","ref":"Validixir.html","title":"Validixir","type":"module"},{"doc":"Takes a validation_result_t() and a functions that takes the candidate in case of a success and returns a validation_result_t() again. This function is used to chain validations. Examples iex&gt; Validixir.Success . make ( 0 ) |&gt; Validixir . and_then ( fn x -&gt; Validixir.Success . make ( x + 1 ) end ) % Validixir.Success { candidate : 1 } iex&gt; Validixir.Failure . make ( [ ] ) |&gt; Validixir . and_then ( fn x -&gt; x + 1 end ) % Validixir.Failure { errors : [ ] }","ref":"Validixir.html#and_then/2","title":"Validixir.and_then/2","type":"function"},{"doc":"Augments a failure's contexts if a failure is passed, else returns the success. Examples iex&gt; Validixir . pure ( 12 ) |&gt; Validixir . augment_contexts ( Hello ) % Validixir.Success { candidate : 12 } iex&gt; error_1 = Validixir.Error . make ( 1 , :message , Context ) iex&gt; error_2 = Validixir.Error . make ( 2 , :message , AnotherContext ) iex&gt; failure = Validixir.Failure . make ( [ error_1 , error_2 ] ) iex&gt; Validixir . augment_contexts ( failure , AdditionalContext ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 1 , message : :message , context : { AdditionalContext , Context } } , % Validixir.Error { candidate : 2 , message : :message , context : { AdditionalContext , AnotherContext } } , ] }","ref":"Validixir.html#augment_contexts/2","title":"Validixir.augment_contexts/2","type":"function"},{"doc":"Augments a failure's messages if a failure is passed, else returns the success. Examples iex&gt; Validixir . pure ( 12 ) |&gt; Validixir . augment_messages ( Hello ) % Validixir.Success { candidate : 12 } iex&gt; error_1 = Validixir.Error . make ( 1 , :message , Context ) iex&gt; error_2 = Validixir.Error . make ( 2 , :another_message , Context ) iex&gt; failure = Validixir.Failure . make ( [ error_1 , error_2 ] ) iex&gt; Validixir . augment_messages ( failure , :additional_message ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 1 , message : { :additional_message , :message } , context : Context } , % Validixir.Error { candidate : 2 , message : { :additional_message , :another_message } , context : Context } ] }","ref":"Validixir.html#augment_messages/2","title":"Validixir.augment_messages/2","type":"function"},{"doc":"Takes a validation result and two functions that are applied as in map_success/2 and map_failure/2 respectivly. Examples iex&gt; success = Validixir.Success . make ( 0 ) iex&gt; Validixir . map ( success , fn a -&gt; a + 1 end , fn _ -&gt; :does_nothing end ) % Validixir.Success { candidate : 1 } iex&gt; failure = Validixir.Failure . make ( [ Validixir.Error . make ( 1 , :hello , :hello ) ] ) iex&gt; Validixir . map ( failure , fn _ -&gt; :does_nothing end , fn err -&gt; % Validixir.Error { err | candidate : 2 } end ) % Validixir.Failure { errors : [ Validixir.Error . make ( 2 , :hello , :hello ) ] }","ref":"Validixir.html#map/3","title":"Validixir.map/3","type":"function"},{"doc":"Applies a function to the errors of a failure. If a success is passed it is returned unchanged. Examples iex&gt; success = Validixir.Success . make ( 0 ) iex&gt; Validixir . map_failure ( success , fn a -&gt; a + 1 end ) % Validixir.Success { candidate : 0 } iex&gt; failure = Validixir.Failure . make ( [ Validixir.Error . make ( 1 , :hello , :hello ) ] ) iex&gt; Validixir . map_failure ( failure , fn err -&gt; % Validixir.Error { err | candidate : 2 } end ) % Validixir.Failure { errors : [ Validixir.Error . make ( 2 , :hello , :hello ) ] }","ref":"Validixir.html#map_failure/2","title":"Validixir.map_failure/2","type":"function"},{"doc":"Applies a function to the candidate of a success. If a failure is passed it is returned unchanged. Examples iex&gt; success = Validixir.Success . make ( 0 ) iex&gt; Validixir . map_success ( success , fn a -&gt; a + 1 end ) % Validixir.Success { candidate : 1 } iex&gt; failure = Validixir.Failure . make ( [ ] ) iex&gt; Validixir . map_success ( failure , fn a -&gt; a + 1 end ) % Validixir.Failure { errors : [ ] }","ref":"Validixir.html#map_success/2","title":"Validixir.map_success/2","type":"function"},{"doc":"Overrides a failure's contexts if a failure is passed, else returns the success. Examples iex&gt; Validixir . pure ( 12 ) |&gt; Validixir . override_contexts ( Hello ) % Validixir.Success { candidate : 12 } iex&gt; error_1 = Validixir.Error . make ( 1 , :message , Context ) iex&gt; error_2 = Validixir.Error . make ( 2 , :another_message , Context ) iex&gt; failure = Validixir.Failure . make ( [ error_1 , error_2 ] ) iex&gt; Validixir . override_contexts ( failure , NewContext ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 1 , message : :message , context : NewContext } , % Validixir.Error { candidate : 2 , message : :another_message , context : NewContext } ] }","ref":"Validixir.html#override_contexts/2","title":"Validixir.override_contexts/2","type":"function"},{"doc":"Overrides a failure's messages if a failure is passed, else returns the success. Examples iex&gt; Validixir . pure ( 12 ) |&gt; Validixir . override_messages ( Hello ) % Validixir.Success { candidate : 12 } iex&gt; error_1 = Validixir.Error . make ( 1 , :message , Context ) iex&gt; error_2 = Validixir.Error . make ( 2 , :another_message , Context ) iex&gt; failure = Validixir.Failure . make ( [ error_1 , error_2 ] ) iex&gt; Validixir . override_messages ( failure , :additional_message ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 1 , message : :additional_message , context : Context } , % Validixir.Error { candidate : 2 , message : :additional_message , context : Context } ] }","ref":"Validixir.html#override_messages/2","title":"Validixir.override_messages/2","type":"function"},{"doc":"Takes a value and lifts it in a validation result, returning a success with the value as its candidate. Examples iex&gt; Validixir . pure ( 12 ) % Validixir.Success { candidate : 12 }","ref":"Validixir.html#pure/1","title":"Validixir.pure/1","type":"function"},{"doc":"This function applies a function wrapped in a validation success to the candidate of a validation success. If both validation results are failures it returns them combined. If only the first one is a failure, this failure is returned unchanged. This function is key in implementing applicatives. Examples iex&gt; s1 = Validixir.Success . make ( fn a -&gt; a + 1 end ) iex&gt; s2 = Validixir.Success . make ( 0 ) iex&gt; Validixir . seq ( s1 , s2 ) % Validixir.Success { candidate : 1 } iex&gt; error = Validixir.Error . make ( :hello , &quot;not allowed&quot; , nil ) iex&gt; failure = Validixir.Failure . make ( [ error ] ) iex&gt; success = Validixir.Success . make ( 1 ) iex&gt; Validixir . seq ( failure , success ) % Validixir.Failure { errors : [ error ] } iex&gt; error1 = Validixir.Error . make ( :hello , &quot;not allowed&quot; , nil ) iex&gt; error2 = Validixir.Error . make ( :world , &quot;not allowed&quot; , nil ) iex&gt; failure1 = Validixir.Failure . make ( [ error1 ] ) iex&gt; failure2 = Validixir.Failure . make ( [ error2 ] ) iex&gt; Validixir . seq ( failure1 , failure2 ) % Validixir.Failure { errors : [ error1 , error2 ] }","ref":"Validixir.html#seq/2","title":"Validixir.seq/2","type":"function"},{"doc":"Takes a list of validation results and returns a validation success containing list of all candidates, if all validation results are successes. Else all failures are combined and a validation failure is returned. Examples iex&gt; Validixir . sequence ( [ Validixir.Success . make ( 1 ) , Validixir.Success . make ( 2 ) ] ) % Validixir.Success { candidate : [ 1 , 2 ] } iex&gt; error1 = Validixir.Error . make ( :hello , &quot;not allowed&quot; , nil ) iex&gt; error2 = Validixir.Error . make ( :world , &quot;not allowed&quot; , nil ) iex&gt; failure1 = Validixir.Failure . make ( [ error1 ] ) iex&gt; failure2 = Validixir.Failure . make ( [ error2 ] ) iex&gt; Validixir . sequence ( [ failure1 , failure2 ] ) % Validixir.Failure { errors : [ error1 , error2 ] }","ref":"Validixir.html#sequence/1","title":"Validixir.sequence/1","type":"function"},{"doc":"Does the same as Validixir.sequence/1 but applies a validation function to all candidates first. Takes an optional context to augment the results, including the index. Uses :seq if none is given. Examples iex&gt; success_fn = fn c -&gt; Validixir.Success . make ( c ) end iex&gt; Validixir . sequence_of ( [ 1 , 2 ] , success_fn ) % Validixir.Success { candidate : [ 1 , 2 ] } iex&gt; failure_fn = fn c -&gt; [ Validixir.Error . make ( c , &quot;not allowed&quot; , nil ) ] |&gt; Validixir.Failure . make ( ) end iex&gt; Validixir . sequence_of ( [ :hello , :world ] , failure_fn ) % Validixir.Failure { errors : [ Validixir.Error . make ( :hello , { { :index , 0 } , &quot;not allowed&quot; } , nil ) , Validixir.Error . make ( :world , { { :index , 1 } , &quot;not allowed&quot; } , nil ) ] }","ref":"Validixir.html#sequence_of/2","title":"Validixir.sequence_of/2","type":"function"},{"doc":"Takes a function that is called iff all validation results are Successes. The call parameters are then the candidates in the respective order. Returns a validation success then, with the candidate being the return value of this function. If there is at least one failure, errors get accumulated and a validation failure is returned. Examples iex&gt; Validixir . validate ( fn a , b -&gt; { a , b } end , [ Validixir.Success . make ( 1 ) , Validixir.Success . make ( 2 ) ] ) % Validixir.Success { candidate : { 1 , 2 } } iex&gt; error1 = Validixir.Error . make ( :hello , &quot;not allowed&quot; , nil ) iex&gt; error2 = Validixir.Error . make ( :world , &quot;not allowed&quot; , nil ) iex&gt; failure1 = Validixir.Failure . make ( [ error1 ] ) iex&gt; failure2 = Validixir.Failure . make ( [ error2 ] ) iex&gt; Validixir . validate ( fn a , b -&gt; { a , b } end , [ failure1 , failure2 ] ) % Validixir.Failure { errors : [ error1 , error2 ] }","ref":"Validixir.html#validate/2","title":"Validixir.validate/2","type":"function"},{"doc":"Applies a list of validation functions to a candidate. Returns a success containing the candidate if each validation function returns a success. Else returns a validation failure containing errors of each failed validation. Takes an optional context as in Validixir.sequence_of/3 . Examples iex&gt; success_fn_1 = fn c -&gt; Validixir.Success . make ( c ) end iex&gt; success_fn_2 = fn _ -&gt; Validixir.Success . make ( 12 ) end iex&gt; Validixir . validate_all ( [ success_fn_1 , success_fn_2 ] , 1 ) % Validixir.Success { candidate : 1 } iex&gt; failure_fn = fn c -&gt; [ Validixir.Error . make ( c , &quot;not allowed&quot; , nil ) ] |&gt; Validixir.Failure . make ( ) end iex&gt; success_fn = fn _ -&gt; Validixir.Success . make ( 12 ) end iex&gt; Validixir . validate_all ( [ failure_fn , success_fn ] , :hello ) % Validixir.Failure { errors : [ Validixir.Error . make ( :hello , { { :index , 0 } , &quot;not allowed&quot; } , nil ) ] }","ref":"Validixir.html#validate_all/2","title":"Validixir.validate_all/2","type":"function"},{"doc":"Returns true if a value is either a [[Validixir.Success]] or a [[Validixir.Failure]], returns false else. Examples iex&gt; Validixir . validation_result? ( Validixir.Success . make ( 12 ) ) true iex&gt; Validixir . validation_result? ( Validixir.Failure . make ( [ ] ) ) true iex&gt; Validixir . validation_result? ( %{ } ) false","ref":"Validixir.html#validation_result?/1","title":"Validixir.validation_result?/1","type":"function"},{"doc":"","ref":"Validixir.html#t:validate_all_return_t/1","title":"Validixir.validate_all_return_t/1","type":"type"},{"doc":"","ref":"Validixir.html#t:validation_fun_t/1","title":"Validixir.validation_fun_t/1","type":"type"},{"doc":"","ref":"Validixir.html#t:validation_result_t/1","title":"Validixir.validation_result_t/1","type":"type"},{"doc":"Module containing data definition and functionality concering an Error. An Error is a struct representing a concrete error in validation. An Error consists of the following: A candidate, representing the value that was validated A message, describing the cause of the Error A context in which the Error occured, e.g. a module or step","ref":"Validixir.Error.html","title":"Validixir.Error","type":"module"},{"doc":"Augments the context of an error Examples iex&gt; Validixir.Error . augment_context ( Validixir.Error . make ( 12 , :message , Context ) , NewContext ) % Validixir.Error { candidate : 12 , message : :message , context : { NewContext , Context } }","ref":"Validixir.Error.html#augment_context/2","title":"Validixir.Error.augment_context/2","type":"function"},{"doc":"Augments the message of an error Examples iex&gt; Validixir.Error . augment_message ( Validixir.Error . make ( 12 , :message , Context ) , :new_message ) % Validixir.Error { candidate : 12 , message : { :new_message , :message } , context : Context }","ref":"Validixir.Error.html#augment_message/2","title":"Validixir.Error.augment_message/2","type":"function"},{"doc":"Smart constructor of an error.","ref":"Validixir.Error.html#make/3","title":"Validixir.Error.make/3","type":"function"},{"doc":"Overrides the context of an error Examples iex&gt; Validixir.Error . with_context ( Validixir.Error . make ( 12 , :message , Context ) , NewContext ) % Validixir.Error { candidate : 12 , message : :message , context : NewContext }","ref":"Validixir.Error.html#with_context/2","title":"Validixir.Error.with_context/2","type":"function"},{"doc":"Overrides the message of an error Examples iex&gt; Validixir.Error . with_message ( Validixir.Error . make ( 12 , :message , Context ) , :new_message ) % Validixir.Error { candidate : 12 , message : :new_message , context : Context }","ref":"Validixir.Error.html#with_message/2","title":"Validixir.Error.with_message/2","type":"function"},{"doc":"","ref":"Validixir.Error.html#t:t/0","title":"Validixir.Error.t/0","type":"type"},{"doc":"Module containing data definition and functionality concering a Failure. An Failure is a struct representing a failed validation. An Failure consists of the following: A list of Errors, displaying multiple causes for the validation to fail.","ref":"Validixir.Failure.html","title":"Validixir.Failure","type":"module"},{"doc":"Combines two errors. That is, appending their error list. Examples iex&gt; error_1 = Validixir.Error . make ( 1 , :not_allowed , SomeContext ) iex&gt; error_2 = Validixir.Error . make ( 2 , :also_not_allowed , SomeContext ) iex&gt; failure_1 = Validixir.Failure . make ( [ error_1 ] ) iex&gt; failure_2 = Validixir.Failure . make ( [ error_2 ] ) iex&gt; Validixir.Failure . combine ( failure_1 , failure_2 ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 1 , message : :not_allowed , context : SomeContext } , % Validixir.Error { candidate : 2 , message : :also_not_allowed , context : SomeContext } ] }","ref":"Validixir.Failure.html#combine/2","title":"Validixir.Failure.combine/2","type":"function"},{"doc":"Returns true if a value is a failure. Examples iex&gt; f = Validixir.Failure . make ( [ ] ) iex&gt; Validixir.Failure . failure? ( f ) true iex&gt; s = Validixir.Success . make ( 1 ) iex&gt; Validixir.Failure . failure? ( s ) false","ref":"Validixir.Failure.html#failure?/1","title":"Validixir.Failure.failure?/1","type":"function"},{"doc":"Smart constructor of a failure.","ref":"Validixir.Failure.html#make/1","title":"Validixir.Failure.make/1","type":"function"},{"doc":"Applies a function to each error in a failure's errors. Examples iex&gt; f = Validixir.Failure . make ( [ 1 , 2 , 3 ] ) iex&gt; Validixir.Failure . map ( f , fn a -&gt; a + 1 end ) % Validixir.Failure { errors : [ 2 , 3 , 4 ] }","ref":"Validixir.Failure.html#map/2","title":"Validixir.Failure.map/2","type":"function"},{"doc":"Overrides the context of all errors of a failure. Examples iex&gt; error_1 = Validixir.Error . make ( 1 , :not_allowed , SomeContext ) iex&gt; error_2 = Validixir.Error . make ( 2 , :not_allowed , SomeOtherContext ) iex&gt; f = Validixir.Failure . make ( [ error_1 , error_2 ] ) iex&gt; Validixir.Failure . override_error_contexts ( f , NewFailureContext ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 1 , message : :not_allowed , context : NewFailureContext } , % Validixir.Error { candidate : 2 , message : :not_allowed , context : NewFailureContext } ] }","ref":"Validixir.Failure.html#override_error_contexts/2","title":"Validixir.Failure.override_error_contexts/2","type":"function"},{"doc":"Overrides the message of all errors of a failure. Examples iex&gt; error_1 = Validixir.Error . make ( 1 , :not_allowed , SomeContext ) iex&gt; error_2 = Validixir.Error . make ( 2 , :also_not_allowed , SomeContext ) iex&gt; f = Validixir.Failure . make ( [ error_1 , error_2 ] ) iex&gt; Validixir.Failure . override_error_messages ( f , :nonono ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 1 , message : :nonono , context : SomeContext } , % Validixir.Error { candidate : 2 , message : :nonono , context : SomeContext } ] }","ref":"Validixir.Failure.html#override_error_messages/2","title":"Validixir.Failure.override_error_messages/2","type":"function"},{"doc":"","ref":"Validixir.Failure.html#t:t/0","title":"Validixir.Failure.t/0","type":"type"},{"doc":"Module containing data definition and functionality concering a Success. An Succes is a struct representing a successful validation. A Success consists of the following: A candidate, representing the value that was validated.","ref":"Validixir.Success.html","title":"Validixir.Success","type":"module"},{"doc":"Smart constructor of a success.","ref":"Validixir.Success.html#make/1","title":"Validixir.Success.make/1","type":"function"},{"doc":"Applies a function to the candidate of a success. Examples iex&gt; Validixir.Success . map ( Validixir.Success . make ( 0 ) , fn a -&gt; a + 1 end ) % Validixir.Success { candidate : 1 }","ref":"Validixir.Success.html#map/2","title":"Validixir.Success.map/2","type":"function"},{"doc":"Returns true if a value is a success. Examples iex&gt; f = Validixir.Failure . make ( [ ] ) iex&gt; Validixir.Success . success? ( f ) false iex&gt; s = Validixir.Success . make ( 1 ) iex&gt; Validixir.Success . success? ( s ) true","ref":"Validixir.Success.html#success?/1","title":"Validixir.Success.success?/1","type":"function"},{"doc":"","ref":"Validixir.Success.html#t:some_inner_t/0","title":"Validixir.Success.some_inner_t/0","type":"type"},{"doc":"","ref":"Validixir.Success.html#t:t/1","title":"Validixir.Success.t/1","type":"type"},{"doc":"This module contains premade validations for basic elixir types and often used functionality.","ref":"Validixir.Validations.html","title":"Validixir.Validations","type":"module"},{"doc":"Returns a validation success if the candidate is an atom, returns a failure else. Examples iex&gt; Validixir.Validations . atom ( :hello ) % Validixir.Success { candidate : :hello } iex&gt; Validixir.Validations . atom ( 12 ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12 , message : :not_an_atom , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#atom/1","title":"Validixir.Validations.atom/1","type":"function"},{"doc":"Returns a validation success if the candidate is a binary, returns a failure else. Examples iex&gt; Validixir.Validations . binary ( &quot;foo&quot; ) % Validixir.Success { candidate : &quot;foo&quot; } iex&gt; Validixir.Validations . binary ( &lt;&lt; 1 :: 3 &gt;&gt; ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : &lt;&lt; 1 :: 3 &gt;&gt; , message : :not_a_binary , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#binary/1","title":"Validixir.Validations.binary/1","type":"function"},{"doc":"Returns a validation success if the candidate is a bitstring, returns a failure else. Examples iex&gt; Validixir.Validations . bitstring ( &quot;foo&quot; ) % Validixir.Success { candidate : &quot;foo&quot; } iex&gt; Validixir.Validations . bitstring ( &lt;&lt; 1 :: 3 &gt;&gt; ) % Validixir.Success { candidate : &lt;&lt; 1 :: 3 &gt;&gt; } iex&gt; Validixir.Validations . bitstring ( 12 ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12 , message : :not_a_bitstring , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#bitstring/1","title":"Validixir.Validations.bitstring/1","type":"function"},{"doc":"Returns a validation success if the candidate is a boolean, returns a failure else. Examples iex&gt; Validixir.Validations . boolean ( true ) % Validixir.Success { candidate : true } iex&gt; Validixir.Validations . boolean ( nil ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : nil , message : :not_a_boolean , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#boolean/1","title":"Validixir.Validations.boolean/1","type":"function"},{"doc":"Returns a validation success if the candidate is an empty list, returns a failure else. Examples iex&gt; Validixir.Validations . empty_list ( [ ] ) % Validixir.Success { candidate : [ ] } iex&gt; Validixir.Validations . empty_list ( [ 1 , 2 , 3 ] ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : [ 1 , 2 , 3 ] , message : :not_an_empty_list , context : Validixir.Validations } ] } iex&gt; Validixir.Validations . empty_list ( %{ } ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : %{ } , message : :not_an_empty_list , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#empty_list/1","title":"Validixir.Validations.empty_list/1","type":"function"},{"doc":"Returns a validation success if the candidate is an exception, returns a failure else. Examples iex&gt; Validixir.Validations . exception ( % RuntimeError { } ) % Validixir.Success { candidate : % RuntimeError { } } iex&gt; Validixir.Validations . exception ( %{ } ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : %{ } , message : :not_an_exception , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#exception/1","title":"Validixir.Validations.exception/1","type":"function"},{"doc":"Returns a validation success if the candidate is a float, returns a failure else. Examples iex&gt; Validixir.Validations . float ( 12.2 ) % Validixir.Success { candidate : 12.2 } iex&gt; Validixir.Validations . float ( 12 ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12 , message : :not_a_float , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#float/1","title":"Validixir.Validations.float/1","type":"function"},{"doc":"Returns a validation success if the candidate is a function, returns a failure else. Examples iex&gt; Validixir.Validations . function ( &amp; Validixir . pure / 1 ) % Validixir.Success { candidate : &amp; Validixir . pure / 1 } iex&gt; Validixir.Validations . function ( 12 ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12 , message : :not_a_function , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#function/1","title":"Validixir.Validations.function/1","type":"function"},{"doc":"Returns a validation success if the candidate is an integer, returns a failure else. Examples iex&gt; Validixir.Validations . integer ( 12 ) % Validixir.Success { candidate : 12 } iex&gt; Validixir.Validations . integer ( 12.2 ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12.2 , message : :not_an_integer , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#integer/1","title":"Validixir.Validations.integer/1","type":"function"},{"doc":"Returns a validation success if the candidate is a list, returns a failure else. Examples iex&gt; Validixir.Validations . list ( [ 1 , 2 , 3 ] ) % Validixir.Success { candidate : [ 1 , 2 , 3 ] } iex&gt; Validixir.Validations . list ( [ ] ) % Validixir.Success { candidate : [ ] } iex&gt; Validixir.Validations . list ( %{ } ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : %{ } , message : :not_a_list , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#list/1","title":"Validixir.Validations.list/1","type":"function"},{"doc":"Returns a validation success if the candidate is a map, returns a failure else. Examples iex&gt; Validixir.Validations . map ( %{ } ) % Validixir.Success { candidate : %{ } } iex&gt; Validixir.Validations . map ( % Validixir.Success { candidate : 12 } ) % Validixir.Success { candidate : % Validixir.Success { candidate : 12 } } iex&gt; Validixir.Validations . map ( [ ] ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : [ ] , message : :not_a_map , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#map/1","title":"Validixir.Validations.map/1","type":"function"},{"doc":"Returns a validation success if the given map contains the given key, returns a failure else. Examples iex&gt; Validixir.Validations . map_key ( %{ hello : :world } , :hello ) % Validixir.Success { candidate : { %{ hello : :world } , :hello } } iex&gt; Validixir.Validations . map_key ( %{ } , :hello ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : { %{ } , :hello } , message : :not_a_key_of_map , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#map_key/2","title":"Validixir.Validations.map_key/2","type":"function"},{"doc":"Returns a validation success if the enum contains the elem, returns a failure else. Examples iex&gt; Validixir.Validations . member ( [ 1 , 2 , 3 ] , 1 ) % Validixir.Success { candidate : { [ 1 , 2 , 3 ] , 1 } } iex&gt; Validixir.Validations . member ( [ ] , 1 ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : { [ ] , 1 } , message : :not_a_member , context : Validixir.Validations } ] } iex&gt; Validixir.Validations . member ( [ 1 , 2 , 3 ] , 12 ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : { [ 1 , 2 , 3 ] , 12 } , message : :not_a_member , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#member/2","title":"Validixir.Validations.member/2","type":"function"},{"doc":"Returns a validation success if the candidate is a negative integer, returns a failure else. Examples iex&gt; Validixir.Validations . neg_integer ( - 12 ) % Validixir.Success { candidate : - 12 } iex&gt; Validixir.Validations . neg_integer ( 0 ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 0 , message : :not_a_negative_integer , context : Validixir.Validations } ] } iex&gt; Validixir.Validations . neg_integer ( 2 ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 2 , message : :not_a_negative_integer , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#neg_integer/1","title":"Validixir.Validations.neg_integer/1","type":"function"},{"doc":"Returns a validation success if the candidate is nil, returns a failure else. Since all other names are special words in elixir, we chose nil? as the function name. Examples iex&gt; Validixir.Validations . nil? ( nil ) % Validixir.Success { candidate : nil } iex&gt; Validixir.Validations . nil? ( 12 ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12 , message : :not_nil , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#nil?/1","title":"Validixir.Validations.nil?/1","type":"function"},{"doc":"Returns a validation success if the candidate is an non-empty list, returns a failure else. Examples iex&gt; Validixir.Validations . non_empty_list ( [ 1 , 2 , 3 ] ) % Validixir.Success { candidate : [ 1 , 2 , 3 ] } iex&gt; Validixir.Validations . non_empty_list ( [ ] ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : [ ] , message : :not_a_non_empty_list , context : Validixir.Validations } ] } iex&gt; Validixir.Validations . non_empty_list ( %{ } ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : %{ } , message : :not_a_non_empty_list , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#non_empty_list/1","title":"Validixir.Validations.non_empty_list/1","type":"function"},{"doc":"Returns a validation success if the enum does not contain the elem, returns a failure else. Examples iex&gt; Validixir.Validations . not_a_member ( [ 1 , 2 , 3 ] , 4 ) % Validixir.Success { candidate : { [ 1 , 2 , 3 ] , 4 } } iex&gt; Validixir.Validations . not_a_member ( [ ] , 1 ) % Validixir.Success { candidate : { [ ] , 1 } } iex&gt; Validixir.Validations . not_a_member ( [ 1 , 2 , 3 ] , 1 ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : { [ 1 , 2 , 3 ] , 1 } , message : :is_a_member , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#not_a_member/2","title":"Validixir.Validations.not_a_member/2","type":"function"},{"doc":"Returns a validation success if the candidate is not nil, returns a failure else. Examples iex&gt; Validixir.Validations . not_nil ( 12 ) % Validixir.Success { candidate : 12 } iex&gt; Validixir.Validations . not_nil ( nil ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : nil , message : :is_nil , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#not_nil/1","title":"Validixir.Validations.not_nil/1","type":"function"},{"doc":"Returns a validation success if the candidate is a number, returns a failure else. Examples iex&gt; Validixir.Validations . number ( 12.2 ) % Validixir.Success { candidate : 12.2 } iex&gt; Validixir.Validations . number ( 12 ) % Validixir.Success { candidate : 12 } iex&gt; Validixir.Validations . number ( nil ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : nil , message : :not_a_number , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#number/1","title":"Validixir.Validations.number/1","type":"function"},{"doc":"Returns a validation success if the candidate is a pid, returns a failure else. Examples iex&gt; Validixir.Validations . pid ( self ( ) ) % Validixir.Success { candidate : self ( ) } iex&gt; Validixir.Validations . pid ( 12 ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12 , message : :not_a_pid , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#pid/1","title":"Validixir.Validations.pid/1","type":"function"},{"doc":"Returns a validation success if the candidate is a port, returns a failure else.","ref":"Validixir.Validations.html#port/1","title":"Validixir.Validations.port/1","type":"function"},{"doc":"Returns a validation success if the candidate is a positive integer, returns a failure else. Examples iex&gt; Validixir.Validations . pos_integer ( 12 ) % Validixir.Success { candidate : 12 } iex&gt; Validixir.Validations . pos_integer ( 0 ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 0 , message : :not_a_positive_integer , context : Validixir.Validations } ] } iex&gt; Validixir.Validations . pos_integer ( - 2 ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : - 2 , message : :not_a_positive_integer , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#pos_integer/1","title":"Validixir.Validations.pos_integer/1","type":"function"},{"doc":"Returns a validation success if the candidate is a reference, returns a failure else. Examples iex&gt; ref = make_ref ( ) iex&gt; Validixir.Validations . reference ( ref ) % Validixir.Success { candidate : ref } iex&gt; Validixir.Validations . reference ( 12 ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : 12 , message : :not_a_reference , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#reference/1","title":"Validixir.Validations.reference/1","type":"function"},{"doc":"Returns a validation success if the candidate is a struct, returns a failure else. Examples iex&gt; Validixir.Validations . struct ( Validixir.Success . make ( &quot;abc&quot; ) ) % Validixir.Success { candidate : Validixir.Success . make ( &quot;abc&quot; ) } iex&gt; Validixir.Validations . struct ( %{ } ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : %{ } , message : :not_a_struct , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#struct/1","title":"Validixir.Validations.struct/1","type":"function"},{"doc":"Always returns a validation success. Examples iex&gt; Validixir.Validations . succeed ( 12 ) % Validixir.Success { candidate : 12 }","ref":"Validixir.Validations.html#succeed/1","title":"Validixir.Validations.succeed/1","type":"function"},{"doc":"Returns a validation success if the candidate is a tuple, returns a failure else. Examples iex&gt; Validixir.Validations . tuple ( { 1 , 2 , 3 } ) % Validixir.Success { candidate : { 1 , 2 , 3 } } iex&gt; Validixir.Validations . tuple ( [ 1 , 2 , 3 ] ) % Validixir.Failure { errors : [ % Validixir.Error { candidate : [ 1 , 2 , 3 ] , message : :not_a_tuple , context : Validixir.Validations } ] }","ref":"Validixir.Validations.html#tuple/1","title":"Validixir.Validations.tuple/1","type":"function"}]